@@ -52,20 +52,20 @@ TerminalDescription tcurrent_info = { NULL };
 
 EditorDescription possible_editors[] =
 {
-        { "Emacs", "emacs", FALSE, "executable", TRUE },
-        { "XEmacs", "xemacs", FALSE, "executable", TRUE },
-        { "vi", "vi", TRUE, "executable", TRUE },
-        { "Go", "go", FALSE, "executable", FALSE },
-        { "gEdit", "gedit", FALSE, "executable", FALSE },
-        { "GWP", "gwp", FALSE, "executable", FALSE },
-        { "Jed", "jed", TRUE, "executable", TRUE },
-        { "Joe", "joe", TRUE, "executable", TRUE },
-        { "Pico", "pico", TRUE, "executable", TRUE },
-        { "vim",  "vim", TRUE, "executable", TRUE },
-        { "gvim",  "gvim", FALSE, "executable", TRUE },
-        { "ed", "ed", TRUE, "executable", FALSE },
+        { "gedit",        "gedit",  FALSE, "executable",  FALSE },
+        { "Emacs",        "emacs",  FALSE, "executable",  TRUE },
+        { "XEmacs",       "xemacs", FALSE, "executable",  TRUE },
+        { "vi",           "vi",     TRUE,  "executable",  TRUE },
+        { "Go",           "go",     FALSE, "executable",  FALSE },
+        { "GWP",          "gwp",    FALSE, "executable",  FALSE },
+        { "Jed",          "jed",    TRUE,  "executable",  TRUE },
+        { "Joe",          "joe",    TRUE,  "executable",  TRUE },
+        { "Pico",         "pico",   TRUE,  "executable",  TRUE },
+        { "vim",          "vim",    TRUE,  "executable",  TRUE },
+        { "gvim",         "gvim",   FALSE, "executable",  TRUE },
+        { "ed",           "ed",     TRUE,  "executable",  FALSE },
         { "GMC/CoolEdit", "gmc -e", FALSE, "mc-internal", FALSE },
-	{ "Nedit", "nedit", FALSE, "executable", FALSE }
+	{ "Nedit",        "nedit",  FALSE, "executable",  FALSE }
 };
 
 BrowserDescription possible_browsers[] =
@@ -129,8 +129,8 @@ edit_read(void)
         eoriginal_info.execution_type = gnome_config_get_string("/editor/Editor/EDITOR_TYPE");
         eoriginal_info.accepts_lineno = gnome_config_get_bool_with_default("/editor/Editor/ACCEPTS_LINE_NO", NULL);
 
-        ecurrent_info.name = gnome_config_get_string("/editor/Editor/EDITNAME=Emacs");
-        ecurrent_info.executable_name = gnome_config_get_string("/editor/Editor/EDITOR=emacs");
+        ecurrent_info.name = gnome_config_get_string("/editor/Editor/EDITNAME=gedit");
+        ecurrent_info.executable_name = gnome_config_get_string("/editor/Editor/EDITOR=gedit");
         ecurrent_info.needs_term = gnome_config_get_bool_with_default("/editor/Editor/NEEDS_TERM=FALSE", NULL);
         ecurrent_info.execution_type = gnome_config_get_string("/editor/Editor/EDITOR_TYPE=executable");
         ecurrent_info.accepts_lineno = gnome_config_get_bool_with_default("/editor/Editor/ACCEPTS_LINE_NO=TRUE", NULL);
@@ -283,7 +283,7 @@ fill_editor_data (EditorDescription *info)
         if (info->use_name) {
                 set_combo_editor (info->name);
                 gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON 
-                                              (gtk_object_get_data (GTK_OBJECT (capplet), "radiodefeditorm")), 
+                                              (gtk_object_get_data (GTK_OBJECT (capplet), "radiodefeditor")), 
                                               TRUE);
         } else {
                 gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON 
@@ -372,7 +372,7 @@ main (int argc, char **argv)
         bindtextdomain (PACKAGE, GNOMELOCALEDIR);
         textdomain (PACKAGE);
 
-        switch (gnome_capplet_init ("gnome-browser-properties", VERSION, argc,
+        switch (gnome_capplet_init ("default-application-properties", VERSION, argc,
                                     argv, NULL, 0, NULL)) {
                 
         case -1:
